summaryrefslogtreecommitdiff
path: root/src/char/fwd.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/char/fwd.hpp')
-rw-r--r--src/char/fwd.hpp25
1 files changed, 24 insertions, 1 deletions
diff --git a/src/char/fwd.hpp b/src/char/fwd.hpp
index 31cd1ba..8086083 100644
--- a/src/char/fwd.hpp
+++ b/src/char/fwd.hpp
@@ -20,8 +20,31 @@
#include "../sanity.hpp"
+#include "../ints/fwd.hpp" // rank 1
+#include "../strings/fwd.hpp" // rank 1
+#include "../compat/fwd.hpp" // rank 2
+#include "../generic/fwd.hpp" // rank 3
+#include "../io/fwd.hpp" // rank 4
+#include "../net/fwd.hpp" // rank 5
+#include "../mmo/fwd.hpp" // rank 6
+#include "../proto2/fwd.hpp" // rank 8
+#include "../high/fwd.hpp" // rank 9
+#include "../wire/fwd.hpp" // rank 9
+// char/fwd.hpp is rank ∞ because it is an executable
+
namespace tmwa
{
-// meh, add more when I feel like it
+namespace char_
+{
+ struct CharConf;
+ struct CharLanConf;
+ struct InterConf;
+
+ struct AuthFifoEntry;
+ struct mmo_map_server;
+
+ struct accreg;
+ // meh, add more when I feel like it
+} // namespace char_
} // namespace tmwa